@@ -18,7 +18,7 @@ class KeyView(View):
         """
         put_data = parse_json(request)
         access_token = put_data['IDT']
-        index = int(put_data['Data'])  # TODO
+        index = int(put_data['Data'])  # noqa TODO: Use this index!
 
         device_user: DeviceUser = get_device_user_by_token(token=access_token)
         privkey = device_user.privkey
