@@ -16,7 +16,7 @@ class LocationDataSizeView(View):
         put_data = parse_json(request)
         print(self, 'put', put_data)
         access_token = put_data['IDT']
-        index = int(put_data['Data'])  # TODO
+        index = int(put_data['Data'])  # noqa TODO: Use this index!
 
         device_user = get_device_user_by_token(token=access_token)
         location_count = Location.objects.filter(device_user=device_user).count()
